# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: search.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import definitions_pb2 as definitions__pb2
from . import groups_pb2 as groups__pb2
from . import peers_pb2 as peers__pb2
from . import messaging_pb2 as messaging__pb2
from . import users_pb2 as users__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='search.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=_b('\342?\026\n\024im.dlg.grpc.services'),
  serialized_pb=_b('\n\x0csearch.proto\x12\x06\x64ialog\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x0cgroups.proto\x1a\x0bpeers.proto\x1a\x0fmessaging.proto\x1a\x0busers.proto\x1a\x13miscellaneous.proto\x1a\x15scalapb/scalapb.proto\",\n\x1cSimpleContactSearchCondition\x12\x0c\n\x04text\x18\x01 \x01(\t\"y\n\x1cSimpleMessageSearchCondition\x12\x1a\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.Peer\x12\x0c\n\x04text\x18\x02 \x01(\t\x12/\n\x0c\x63ontent_type\x18\x03 \x01(\x0e\x32\x19.dialog.SearchContentType\"r\n\x19SimplePeerSearchCondition\x12)\n\tpeer_type\x18\x01 \x01(\x0e\x32\x16.dialog.SearchPeerType\x12*\n\x04text\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"8\n SimpleUserProfileSearchCondition\x12\x14\n\x0cquery_string\x18\x01 \x01(\t\"\x0b\n\tcriterion\"\x8a\x02\n\x15SimpleSearchCondition\x12\x37\n\x07\x63ontact\x18\x01 \x01(\x0b\x32$.dialog.SimpleContactSearchConditionH\x00\x12\x37\n\x07message\x18\x02 \x01(\x0b\x32$.dialog.SimpleMessageSearchConditionH\x00\x12\x31\n\x04peer\x18\x03 \x01(\x0b\x32!.dialog.SimplePeerSearchConditionH\x00\x12?\n\x0buserProfile\x18\x04 \x01(\x0b\x32(.dialog.SimpleUserProfileSearchConditionH\x00\x42\x0b\n\tcriterion\"\xc3\x03\n\x0fSearchCondition\x12\x42\n\x17searchPeerTypeCondition\x18\x01 \x01(\x0b\x32\x1f.dialog.SearchPeerTypeConditionH\x00\x12\x32\n\x0fsearchPieceText\x18\x02 \x01(\x0b\x32\x17.dialog.SearchPieceTextH\x00\x12\x38\n\x12searchAndCondition\x18\x03 \x01(\x0b\x32\x1a.dialog.SearchAndConditionH\x00\x12\x36\n\x11searchOrCondition\x18\x04 \x01(\x0b\x32\x19.dialog.SearchOrConditionH\x00\x12:\n\x13searchPeerCondition\x18\x05 \x01(\x0b\x32\x1b.dialog.SearchPeerConditionH\x00\x12>\n\x15searchPeerContentType\x18\x06 \x01(\x0b\x32\x1d.dialog.SearchPeerContentTypeH\x00\x12\x42\n\x17searchSenderIdConfition\x18\x07 \x01(\x0b\x32\x1f.dialog.SearchSenderIdConfitionH\x00\x42\x06\n\x04\x62ody\"R\n\x17SearchPeerTypeCondition\x12\x37\n\tpeer_type\x18\x01 \x01(\x0e\x32\x16.dialog.SearchPeerTypeB\x0c\x8a\xea\x30\x08\n\x06hidden\".\n\x0fSearchPieceText\x12\x1b\n\x05query\x18\x01 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\"O\n\x12SearchAndCondition\x12\x39\n\tand_query\x18\x01 \x03(\x0b\x32\x17.dialog.SearchConditionB\r\x8a\xea\x30\t\n\x07visible\"M\n\x11SearchOrCondition\x12\x38\n\x08or_query\x18\x02 \x03(\x0b\x32\x17.dialog.SearchConditionB\r\x8a\xea\x30\t\n\x07visible\"C\n\x13SearchPeerCondition\x12,\n\x04peer\x18\x01 \x01(\x0b\x32\x0f.dialog.OutPeerB\r\x8a\xea\x30\t\n\x07visible\"W\n\x15SearchPeerContentType\x12>\n\x0c\x63ontent_type\x18\x01 \x01(\x0e\x32\x19.dialog.SearchContentTypeB\r\x8a\xea\x30\t\n\x07visible\";\n\x17SearchSenderIdConfition\x12 \n\tsender_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\"\xde\x03\n\x10PeerSearchResult\x12)\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x05title\x18\x02 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\x12/\n\tshortname\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12?\n\x0b\x64\x65scription\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x41\n\rmembers_count\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\r\x8a\xea\x30\t\n\x07visible\x12#\n\x0c\x64\x61te_created\x18\x05 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12;\n\x07\x63reator\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\r\x8a\xea\x30\t\n\x07visible\x12<\n\tis_public\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\x12-\n\tis_joined\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\xa9\x01\n\x11RequestPeerSearch\x12\x34\n\x05query\x18\x01 \x03(\x0b\x32\x17.dialog.SearchConditionB\x0c\x8a\xea\x30\x08\n\x06hidden\x12@\n\roptimizations\x18\x02 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xf5\x01\n\x12ResponsePeerSearch\x12\x30\n\x0esearch_results\x18\x01 \x03(\x0b\x32\x18.dialog.PeerSearchResult\x12\x1b\n\x05users\x18\x02 \x03(\x0b\x32\x0c.dialog.User\x12\x1d\n\x06groups\x18\x03 \x03(\x0b\x32\r.dialog.Group\x12\'\n\nuser_peers\x18\x04 \x03(\x0b\x32\x13.dialog.UserOutPeer\x12)\n\x0bgroup_peers\x18\x05 \x03(\x0b\x32\x14.dialog.GroupOutPeer:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"T\n\x12RequestResolvePeer\x12 \n\tshortname\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"S\n\x13ResponseResolvePeer\x12\x1d\n\x04peer\x18\x01 \x01(\x0b\x32\x0f.dialog.OutPeer:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\xd3\x01\n\x13MessageSearchResult\x12)\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03rid\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x64\x61te\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12 \n\tsender_id\x18\x04 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x36\n\x07\x63ontent\x18\x05 \x01(\x0b\x32\x16.dialog.MessageContentB\r\x8a\xea\x30\t\n\x07visible\"@\n\x11MessageSearchItem\x12+\n\x06result\x18\x01 \x01(\x0b\x32\x1b.dialog.MessageSearchResult\"\x98\x03\n\x1dResponseMessageSearchResponse\x12@\n\x0esearch_results\x18\x01 \x03(\x0b\x32\x19.dialog.MessageSearchItemB\r\x8a\xea\x30\t\n\x07visible\x12*\n\x05users\x18\x02 \x03(\x0b\x32\x0c.dialog.UserB\r\x8a\xea\x30\t\n\x07visible\x12,\n\x06groups\x18\x03 \x03(\x0b\x32\r.dialog.GroupB\r\x8a\xea\x30\t\n\x07visible\x12\x42\n\x0fload_more_state\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.BytesValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12:\n\x0euser_out_peers\x18\x05 \x03(\x0b\x32\x13.dialog.UserOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12<\n\x0fgroup_out_peers\x18\x06 \x03(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\xac\x01\n\x14RequestMessageSearch\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32\x17.dialog.SearchConditionB\x0c\x8a\xea\x30\x08\n\x06hidden\x12@\n\roptimizations\x18\x02 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xa1\x01\n\x18RequestMessageSearchMore\x12%\n\x0fload_more_state\x18\x01 \x01(\x0c\x42\x0c\x8a\xea\x30\x08\n\x06hidden\x12@\n\roptimizations\x18\x02 \x03(\x0e\x32\x1a.dialog.UpdateOptimizationB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x97\x01\n\x13RequestSimpleSearch\x12/\n\x08\x63riteria\x18\x01 \x03(\x0b\x32\x1d.dialog.SimpleSearchCondition\x12\x31\n\roptimizations\x18\x02 \x03(\x0e\x32\x1a.dialog.UpdateOptimization:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x83\x01\n\x17RequestSimpleSearchMore\x12\x17\n\x0fload_more_state\x18\x01 \x01(\x0c\x12\x31\n\roptimizations\x18\x02 \x03(\x0e\x32\x1a.dialog.UpdateOptimization:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x7f\n\x18RequestFieldAutocomplete\x12!\n\nfield_name\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\"\n\x0b\x66ield_value\x18\x02 \x01(\tB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x81\x01\n\x19ResponseFieldAutocomplete\x12!\n\nfield_name\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\"\n\x0b\x66ield_value\x18\x02 \x03(\tB\r\x8a\xea\x30\t\n\x07visible:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\xa7\x02\n(RequestLoadUserSearchByPredicatesResults\x12:\n\npredicates\x18\x01 \x03(\x0b\x32\x17.dialog.SearchPredicateB\r\x8a\xea\x30\t\n\x07visible\x12\x1f\n\x08group_id\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12:\n\x05query\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05limit\x18\x04 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12&\n\x0frequired_fields\x18\x05 \x03(\tB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"T\n\tUserMatch\x12\x1e\n\x07user_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\'\n\x10match_predicates\x18\x02 \x01(\x08\x42\r\x8a\xea\x30\t\n\x07visible\"\xa0\x01\n)ResponseLoadUserSearchByPredicatesResults\x12/\n\x05users\x18\x01 \x03(\x0b\x32\x11.dialog.UserMatchB\r\x8a\xea\x30\t\n\x07visible\x12#\n\x0cresult_count\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\xa3\x01\n&RequestLoadUserSearchByPredicatesCount\x12:\n\npredicates\x18\x01 \x03(\x0b\x32\x17.dialog.SearchPredicateB\r\x8a\xea\x30\t\n\x07visible\x12\x1f\n\x08group_id\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"m\n\'ResponseLoadUserSearchByPredicatesCount\x12#\n\x0cresult_count\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse*\x7f\n\x0eSearchPeerType\x12\x1a\n\x16SEARCHPEERTYPE_UNKNOWN\x10\x00\x12\x19\n\x15SEARCHPEERTYPE_GROUPS\x10\x01\x12\x1b\n\x17SEARCHPEERTYPE_CONTACTS\x10\x02\x12\x19\n\x15SEARCHPEERTYPE_PUBLIC\x10\x03*\xc5\x01\n\x11SearchContentType\x12\x1d\n\x19SEARCHCONTENTTYPE_UNKNOWN\x10\x00\x12\x19\n\x15SEARCHCONTENTTYPE_ANY\x10\x01\x12\x1a\n\x16SEARCHCONTENTTYPE_TEXT\x10\x02\x12\x1b\n\x17SEARCHCONTENTTYPE_LINKS\x10\x03\x12\x1f\n\x1bSEARCHCONTENTTYPE_DOCUMENTS\x10\x04\x12\x1c\n\x18SEARCHCONTENTTYPE_PHOTOS\x10\x05\x32\x97\n\n\x06Search\x12j\n\nPeerSearch\x12\x19.dialog.RequestPeerSearch\x1a\x1a.dialog.ResponsePeerSearch\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/v1/grpc/Search/PeerSearch:\x01*\x12n\n\x0bResolvePeer\x12\x1a.dialog.RequestResolvePeer\x1a\x1b.dialog.ResponseResolvePeer\"&\x82\xd3\xe4\x93\x02 \"\x1b/v1/grpc/Search/ResolvePeer:\x01*\x12~\n\rMessageSearch\x12\x1c.dialog.RequestMessageSearch\x1a%.dialog.ResponseMessageSearchResponse\"(\x82\xd3\xe4\x93\x02\"\"\x1d/v1/grpc/Search/MessageSearch:\x01*\x12\x8a\x01\n\x11MessageSearchMore\x12 .dialog.RequestMessageSearchMore\x1a%.dialog.ResponseMessageSearchResponse\",\x82\xd3\xe4\x93\x02&\"!/v1/grpc/Search/MessageSearchMore:\x01*\x12{\n\x0cSimpleSearch\x12\x1b.dialog.RequestSimpleSearch\x1a%.dialog.ResponseMessageSearchResponse\"\'\x82\xd3\xe4\x93\x02!\"\x1c/v1/grpc/Search/SimpleSearch:\x01*\x12\x87\x01\n\x10SimpleSearchMore\x12\x1f.dialog.RequestSimpleSearchMore\x1a%.dialog.ResponseMessageSearchResponse\"+\x82\xd3\xe4\x93\x02%\" /v1/grpc/Search/SimpleSearchMore:\x01*\x12\x92\x01\n\x17\x41utocompleteSuggestions\x12 .dialog.RequestFieldAutocomplete\x1a!.dialog.ResponseFieldAutocomplete\"2\x82\xd3\xe4\x93\x02,\"\'/v1/grpc/Search/AutocompleteSuggestions:\x01*\x12\xc6\x01\n!LoadUserSearchByPredicatesResults\x12\x30.dialog.RequestLoadUserSearchByPredicatesResults\x1a\x31.dialog.ResponseLoadUserSearchByPredicatesResults\"<\x82\xd3\xe4\x93\x02\x36\"1/v1/grpc/Search/LoadUserSearchByPredicatesResults:\x01*\x12\xbe\x01\n\x1fLoadUserSearchByPredicatesCount\x12..dialog.RequestLoadUserSearchByPredicatesCount\x1a/.dialog.ResponseLoadUserSearchByPredicatesCount\":\x82\xd3\xe4\x93\x02\x34\"//v1/grpc/Search/LoadUserSearchByPredicatesCount:\x01*B\x19\xe2?\x16\n\x14im.dlg.grpc.servicesb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,groups__pb2.DESCRIPTOR,peers__pb2.DESCRIPTOR,messaging__pb2.DESCRIPTOR,users__pb2.DESCRIPTOR,miscellaneous__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])

_SEARCHPEERTYPE = _descriptor.EnumDescriptor(
  name='SearchPeerType',
  full_name='dialog.SearchPeerType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SEARCHPEERTYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEARCHPEERTYPE_GROUPS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEARCHPEERTYPE_CONTACTS', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEARCHPEERTYPE_PUBLIC', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5271,
  serialized_end=5398,
)
_sym_db.RegisterEnumDescriptor(_SEARCHPEERTYPE)

SearchPeerType = enum_type_wrapper.EnumTypeWrapper(_SEARCHPEERTYPE)
_SEARCHCONTENTTYPE = _descriptor.EnumDescriptor(
  name='SearchContentType',
  full_name='dialog.SearchContentType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SEARCHCONTENTTYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEARCHCONTENTTYPE_ANY', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEARCHCONTENTTYPE_TEXT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEARCHCONTENTTYPE_LINKS', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEARCHCONTENTTYPE_DOCUMENTS', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEARCHCONTENTTYPE_PHOTOS', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5401,
  serialized_end=5598,
)
_sym_db.RegisterEnumDescriptor(_SEARCHCONTENTTYPE)

SearchContentType = enum_type_wrapper.EnumTypeWrapper(_SEARCHCONTENTTYPE)
SEARCHPEERTYPE_UNKNOWN = 0
SEARCHPEERTYPE_GROUPS = 1
SEARCHPEERTYPE_CONTACTS = 2
SEARCHPEERTYPE_PUBLIC = 3
SEARCHCONTENTTYPE_UNKNOWN = 0
SEARCHCONTENTTYPE_ANY = 1
SEARCHCONTENTTYPE_TEXT = 2
SEARCHCONTENTTYPE_LINKS = 3
SEARCHCONTENTTYPE_DOCUMENTS = 4
SEARCHCONTENTTYPE_PHOTOS = 5



_SIMPLECONTACTSEARCHCONDITION = _descriptor.Descriptor(
  name='SimpleContactSearchCondition',
  full_name='dialog.SimpleContactSearchCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='dialog.SimpleContactSearchCondition.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=206,
  serialized_end=250,
)


_SIMPLEMESSAGESEARCHCONDITION = _descriptor.Descriptor(
  name='SimpleMessageSearchCondition',
  full_name='dialog.SimpleMessageSearchCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.SimpleMessageSearchCondition.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='dialog.SimpleMessageSearchCondition.text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_type', full_name='dialog.SimpleMessageSearchCondition.content_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=373,
)


_SIMPLEPEERSEARCHCONDITION = _descriptor.Descriptor(
  name='SimplePeerSearchCondition',
  full_name='dialog.SimplePeerSearchCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer_type', full_name='dialog.SimplePeerSearchCondition.peer_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='dialog.SimplePeerSearchCondition.text', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=375,
  serialized_end=489,
)


_SIMPLEUSERPROFILESEARCHCONDITION = _descriptor.Descriptor(
  name='SimpleUserProfileSearchCondition',
  full_name='dialog.SimpleUserProfileSearchCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query_string', full_name='dialog.SimpleUserProfileSearchCondition.query_string', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=491,
  serialized_end=547,
)


_CRITERION = _descriptor.Descriptor(
  name='criterion',
  full_name='dialog.criterion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=549,
  serialized_end=560,
)


_SIMPLESEARCHCONDITION = _descriptor.Descriptor(
  name='SimpleSearchCondition',
  full_name='dialog.SimpleSearchCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='contact', full_name='dialog.SimpleSearchCondition.contact', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='dialog.SimpleSearchCondition.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.SimpleSearchCondition.peer', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userProfile', full_name='dialog.SimpleSearchCondition.userProfile', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='criterion', full_name='dialog.SimpleSearchCondition.criterion',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=563,
  serialized_end=829,
)


_SEARCHCONDITION = _descriptor.Descriptor(
  name='SearchCondition',
  full_name='dialog.SearchCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='searchPeerTypeCondition', full_name='dialog.SearchCondition.searchPeerTypeCondition', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='searchPieceText', full_name='dialog.SearchCondition.searchPieceText', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='searchAndCondition', full_name='dialog.SearchCondition.searchAndCondition', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='searchOrCondition', full_name='dialog.SearchCondition.searchOrCondition', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='searchPeerCondition', full_name='dialog.SearchCondition.searchPeerCondition', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='searchPeerContentType', full_name='dialog.SearchCondition.searchPeerContentType', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='searchSenderIdConfition', full_name='dialog.SearchCondition.searchSenderIdConfition', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='body', full_name='dialog.SearchCondition.body',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=832,
  serialized_end=1283,
)


_SEARCHPEERTYPECONDITION = _descriptor.Descriptor(
  name='SearchPeerTypeCondition',
  full_name='dialog.SearchPeerTypeCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer_type', full_name='dialog.SearchPeerTypeCondition.peer_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1285,
  serialized_end=1367,
)


_SEARCHPIECETEXT = _descriptor.Descriptor(
  name='SearchPieceText',
  full_name='dialog.SearchPieceText',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='dialog.SearchPieceText.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1369,
  serialized_end=1415,
)


_SEARCHANDCONDITION = _descriptor.Descriptor(
  name='SearchAndCondition',
  full_name='dialog.SearchAndCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='and_query', full_name='dialog.SearchAndCondition.and_query', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1417,
  serialized_end=1496,
)


_SEARCHORCONDITION = _descriptor.Descriptor(
  name='SearchOrCondition',
  full_name='dialog.SearchOrCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='or_query', full_name='dialog.SearchOrCondition.or_query', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1498,
  serialized_end=1575,
)


_SEARCHPEERCONDITION = _descriptor.Descriptor(
  name='SearchPeerCondition',
  full_name='dialog.SearchPeerCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.SearchPeerCondition.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1577,
  serialized_end=1644,
)


_SEARCHPEERCONTENTTYPE = _descriptor.Descriptor(
  name='SearchPeerContentType',
  full_name='dialog.SearchPeerContentType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content_type', full_name='dialog.SearchPeerContentType.content_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1646,
  serialized_end=1733,
)


_SEARCHSENDERIDCONFITION = _descriptor.Descriptor(
  name='SearchSenderIdConfition',
  full_name='dialog.SearchSenderIdConfition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender_id', full_name='dialog.SearchSenderIdConfition.sender_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1735,
  serialized_end=1794,
)


_PEERSEARCHRESULT = _descriptor.Descriptor(
  name='PeerSearchResult',
  full_name='dialog.PeerSearchResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.PeerSearchResult.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.PeerSearchResult.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shortname', full_name='dialog.PeerSearchResult.shortname', index=2,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='dialog.PeerSearchResult.description', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='members_count', full_name='dialog.PeerSearchResult.members_count', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_created', full_name='dialog.PeerSearchResult.date_created', index=5,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creator', full_name='dialog.PeerSearchResult.creator', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_public', full_name='dialog.PeerSearchResult.is_public', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_joined', full_name='dialog.PeerSearchResult.is_joined', index=8,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1797,
  serialized_end=2275,
)


_REQUESTPEERSEARCH = _descriptor.Descriptor(
  name='RequestPeerSearch',
  full_name='dialog.RequestPeerSearch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='dialog.RequestPeerSearch.query', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestPeerSearch.optimizations', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2278,
  serialized_end=2447,
)


_RESPONSEPEERSEARCH = _descriptor.Descriptor(
  name='ResponsePeerSearch',
  full_name='dialog.ResponsePeerSearch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='search_results', full_name='dialog.ResponsePeerSearch.search_results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='users', full_name='dialog.ResponsePeerSearch.users', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groups', full_name='dialog.ResponsePeerSearch.groups', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_peers', full_name='dialog.ResponsePeerSearch.user_peers', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_peers', full_name='dialog.ResponsePeerSearch.group_peers', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2450,
  serialized_end=2695,
)


_REQUESTRESOLVEPEER = _descriptor.Descriptor(
  name='RequestResolvePeer',
  full_name='dialog.RequestResolvePeer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='shortname', full_name='dialog.RequestResolvePeer.shortname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2697,
  serialized_end=2781,
)


_RESPONSERESOLVEPEER = _descriptor.Descriptor(
  name='ResponseResolvePeer',
  full_name='dialog.ResponseResolvePeer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.ResponseResolvePeer.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2783,
  serialized_end=2866,
)


_MESSAGESEARCHRESULT = _descriptor.Descriptor(
  name='MessageSearchResult',
  full_name='dialog.MessageSearchResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.MessageSearchResult.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rid', full_name='dialog.MessageSearchResult.rid', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.MessageSearchResult.date', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender_id', full_name='dialog.MessageSearchResult.sender_id', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='dialog.MessageSearchResult.content', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2869,
  serialized_end=3080,
)


_MESSAGESEARCHITEM = _descriptor.Descriptor(
  name='MessageSearchItem',
  full_name='dialog.MessageSearchItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dialog.MessageSearchItem.result', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3082,
  serialized_end=3146,
)


_RESPONSEMESSAGESEARCHRESPONSE = _descriptor.Descriptor(
  name='ResponseMessageSearchResponse',
  full_name='dialog.ResponseMessageSearchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='search_results', full_name='dialog.ResponseMessageSearchResponse.search_results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='users', full_name='dialog.ResponseMessageSearchResponse.users', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groups', full_name='dialog.ResponseMessageSearchResponse.groups', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='load_more_state', full_name='dialog.ResponseMessageSearchResponse.load_more_state', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_out_peers', full_name='dialog.ResponseMessageSearchResponse.user_out_peers', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_out_peers', full_name='dialog.ResponseMessageSearchResponse.group_out_peers', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3149,
  serialized_end=3557,
)


_REQUESTMESSAGESEARCH = _descriptor.Descriptor(
  name='RequestMessageSearch',
  full_name='dialog.RequestMessageSearch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='dialog.RequestMessageSearch.query', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestMessageSearch.optimizations', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3560,
  serialized_end=3732,
)


_REQUESTMESSAGESEARCHMORE = _descriptor.Descriptor(
  name='RequestMessageSearchMore',
  full_name='dialog.RequestMessageSearchMore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_more_state', full_name='dialog.RequestMessageSearchMore.load_more_state', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestMessageSearchMore.optimizations', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3735,
  serialized_end=3896,
)


_REQUESTSIMPLESEARCH = _descriptor.Descriptor(
  name='RequestSimpleSearch',
  full_name='dialog.RequestSimpleSearch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='criteria', full_name='dialog.RequestSimpleSearch.criteria', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestSimpleSearch.optimizations', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3899,
  serialized_end=4050,
)


_REQUESTSIMPLESEARCHMORE = _descriptor.Descriptor(
  name='RequestSimpleSearchMore',
  full_name='dialog.RequestSimpleSearchMore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_more_state', full_name='dialog.RequestSimpleSearchMore.load_more_state', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='optimizations', full_name='dialog.RequestSimpleSearchMore.optimizations', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4053,
  serialized_end=4184,
)


_REQUESTFIELDAUTOCOMPLETE = _descriptor.Descriptor(
  name='RequestFieldAutocomplete',
  full_name='dialog.RequestFieldAutocomplete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='field_name', full_name='dialog.RequestFieldAutocomplete.field_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_value', full_name='dialog.RequestFieldAutocomplete.field_value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4186,
  serialized_end=4313,
)


_RESPONSEFIELDAUTOCOMPLETE = _descriptor.Descriptor(
  name='ResponseFieldAutocomplete',
  full_name='dialog.ResponseFieldAutocomplete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='field_name', full_name='dialog.ResponseFieldAutocomplete.field_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_value', full_name='dialog.ResponseFieldAutocomplete.field_value', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4316,
  serialized_end=4445,
)


_REQUESTLOADUSERSEARCHBYPREDICATESRESULTS = _descriptor.Descriptor(
  name='RequestLoadUserSearchByPredicatesResults',
  full_name='dialog.RequestLoadUserSearchByPredicatesResults',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='predicates', full_name='dialog.RequestLoadUserSearchByPredicatesResults.predicates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.RequestLoadUserSearchByPredicatesResults.group_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='query', full_name='dialog.RequestLoadUserSearchByPredicatesResults.query', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='dialog.RequestLoadUserSearchByPredicatesResults.limit', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='required_fields', full_name='dialog.RequestLoadUserSearchByPredicatesResults.required_fields', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4448,
  serialized_end=4743,
)


_USERMATCH = _descriptor.Descriptor(
  name='UserMatch',
  full_name='dialog.UserMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='dialog.UserMatch.user_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_predicates', full_name='dialog.UserMatch.match_predicates', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4745,
  serialized_end=4829,
)


_RESPONSELOADUSERSEARCHBYPREDICATESRESULTS = _descriptor.Descriptor(
  name='ResponseLoadUserSearchByPredicatesResults',
  full_name='dialog.ResponseLoadUserSearchByPredicatesResults',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='users', full_name='dialog.ResponseLoadUserSearchByPredicatesResults.users', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result_count', full_name='dialog.ResponseLoadUserSearchByPredicatesResults.result_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4832,
  serialized_end=4992,
)


_REQUESTLOADUSERSEARCHBYPREDICATESCOUNT = _descriptor.Descriptor(
  name='RequestLoadUserSearchByPredicatesCount',
  full_name='dialog.RequestLoadUserSearchByPredicatesCount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='predicates', full_name='dialog.RequestLoadUserSearchByPredicatesCount.predicates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.RequestLoadUserSearchByPredicatesCount.group_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4995,
  serialized_end=5158,
)


_RESPONSELOADUSERSEARCHBYPREDICATESCOUNT = _descriptor.Descriptor(
  name='ResponseLoadUserSearchByPredicatesCount',
  full_name='dialog.ResponseLoadUserSearchByPredicatesCount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result_count', full_name='dialog.ResponseLoadUserSearchByPredicatesCount.result_count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5160,
  serialized_end=5269,
)

_SIMPLEMESSAGESEARCHCONDITION.fields_by_name['peer'].message_type = peers__pb2._PEER
_SIMPLEMESSAGESEARCHCONDITION.fields_by_name['content_type'].enum_type = _SEARCHCONTENTTYPE
_SIMPLEPEERSEARCHCONDITION.fields_by_name['peer_type'].enum_type = _SEARCHPEERTYPE
_SIMPLEPEERSEARCHCONDITION.fields_by_name['text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SIMPLESEARCHCONDITION.fields_by_name['contact'].message_type = _SIMPLECONTACTSEARCHCONDITION
_SIMPLESEARCHCONDITION.fields_by_name['message'].message_type = _SIMPLEMESSAGESEARCHCONDITION
_SIMPLESEARCHCONDITION.fields_by_name['peer'].message_type = _SIMPLEPEERSEARCHCONDITION
_SIMPLESEARCHCONDITION.fields_by_name['userProfile'].message_type = _SIMPLEUSERPROFILESEARCHCONDITION
_SIMPLESEARCHCONDITION.oneofs_by_name['criterion'].fields.append(
  _SIMPLESEARCHCONDITION.fields_by_name['contact'])
_SIMPLESEARCHCONDITION.fields_by_name['contact'].containing_oneof = _SIMPLESEARCHCONDITION.oneofs_by_name['criterion']
_SIMPLESEARCHCONDITION.oneofs_by_name['criterion'].fields.append(
  _SIMPLESEARCHCONDITION.fields_by_name['message'])
_SIMPLESEARCHCONDITION.fields_by_name['message'].containing_oneof = _SIMPLESEARCHCONDITION.oneofs_by_name['criterion']
_SIMPLESEARCHCONDITION.oneofs_by_name['criterion'].fields.append(
  _SIMPLESEARCHCONDITION.fields_by_name['peer'])
_SIMPLESEARCHCONDITION.fields_by_name['peer'].containing_oneof = _SIMPLESEARCHCONDITION.oneofs_by_name['criterion']
_SIMPLESEARCHCONDITION.oneofs_by_name['criterion'].fields.append(
  _SIMPLESEARCHCONDITION.fields_by_name['userProfile'])
_SIMPLESEARCHCONDITION.fields_by_name['userProfile'].containing_oneof = _SIMPLESEARCHCONDITION.oneofs_by_name['criterion']
_SEARCHCONDITION.fields_by_name['searchPeerTypeCondition'].message_type = _SEARCHPEERTYPECONDITION
_SEARCHCONDITION.fields_by_name['searchPieceText'].message_type = _SEARCHPIECETEXT
_SEARCHCONDITION.fields_by_name['searchAndCondition'].message_type = _SEARCHANDCONDITION
_SEARCHCONDITION.fields_by_name['searchOrCondition'].message_type = _SEARCHORCONDITION
_SEARCHCONDITION.fields_by_name['searchPeerCondition'].message_type = _SEARCHPEERCONDITION
_SEARCHCONDITION.fields_by_name['searchPeerContentType'].message_type = _SEARCHPEERCONTENTTYPE
_SEARCHCONDITION.fields_by_name['searchSenderIdConfition'].message_type = _SEARCHSENDERIDCONFITION
_SEARCHCONDITION.oneofs_by_name['body'].fields.append(
  _SEARCHCONDITION.fields_by_name['searchPeerTypeCondition'])
_SEARCHCONDITION.fields_by_name['searchPeerTypeCondition'].containing_oneof = _SEARCHCONDITION.oneofs_by_name['body']
_SEARCHCONDITION.oneofs_by_name['body'].fields.append(
  _SEARCHCONDITION.fields_by_name['searchPieceText'])
_SEARCHCONDITION.fields_by_name['searchPieceText'].containing_oneof = _SEARCHCONDITION.oneofs_by_name['body']
_SEARCHCONDITION.oneofs_by_name['body'].fields.append(
  _SEARCHCONDITION.fields_by_name['searchAndCondition'])
_SEARCHCONDITION.fields_by_name['searchAndCondition'].containing_oneof = _SEARCHCONDITION.oneofs_by_name['body']
_SEARCHCONDITION.oneofs_by_name['body'].fields.append(
  _SEARCHCONDITION.fields_by_name['searchOrCondition'])
_SEARCHCONDITION.fields_by_name['searchOrCondition'].containing_oneof = _SEARCHCONDITION.oneofs_by_name['body']
_SEARCHCONDITION.oneofs_by_name['body'].fields.append(
  _SEARCHCONDITION.fields_by_name['searchPeerCondition'])
_SEARCHCONDITION.fields_by_name['searchPeerCondition'].containing_oneof = _SEARCHCONDITION.oneofs_by_name['body']
_SEARCHCONDITION.oneofs_by_name['body'].fields.append(
  _SEARCHCONDITION.fields_by_name['searchPeerContentType'])
_SEARCHCONDITION.fields_by_name['searchPeerContentType'].containing_oneof = _SEARCHCONDITION.oneofs_by_name['body']
_SEARCHCONDITION.oneofs_by_name['body'].fields.append(
  _SEARCHCONDITION.fields_by_name['searchSenderIdConfition'])
_SEARCHCONDITION.fields_by_name['searchSenderIdConfition'].containing_oneof = _SEARCHCONDITION.oneofs_by_name['body']
_SEARCHPEERTYPECONDITION.fields_by_name['peer_type'].enum_type = _SEARCHPEERTYPE
_SEARCHANDCONDITION.fields_by_name['and_query'].message_type = _SEARCHCONDITION
_SEARCHORCONDITION.fields_by_name['or_query'].message_type = _SEARCHCONDITION
_SEARCHPEERCONDITION.fields_by_name['peer'].message_type = peers__pb2._OUTPEER
_SEARCHPEERCONTENTTYPE.fields_by_name['content_type'].enum_type = _SEARCHCONTENTTYPE
_PEERSEARCHRESULT.fields_by_name['peer'].message_type = peers__pb2._PEER
_PEERSEARCHRESULT.fields_by_name['shortname'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PEERSEARCHRESULT.fields_by_name['description'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PEERSEARCHRESULT.fields_by_name['members_count'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_PEERSEARCHRESULT.fields_by_name['creator'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_PEERSEARCHRESULT.fields_by_name['is_public'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_PEERSEARCHRESULT.fields_by_name['is_joined'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_REQUESTPEERSEARCH.fields_by_name['query'].message_type = _SEARCHCONDITION
_REQUESTPEERSEARCH.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_RESPONSEPEERSEARCH.fields_by_name['search_results'].message_type = _PEERSEARCHRESULT
_RESPONSEPEERSEARCH.fields_by_name['users'].message_type = users__pb2._USER
_RESPONSEPEERSEARCH.fields_by_name['groups'].message_type = groups__pb2._GROUP
_RESPONSEPEERSEARCH.fields_by_name['user_peers'].message_type = peers__pb2._USEROUTPEER
_RESPONSEPEERSEARCH.fields_by_name['group_peers'].message_type = peers__pb2._GROUPOUTPEER
_RESPONSERESOLVEPEER.fields_by_name['peer'].message_type = peers__pb2._OUTPEER
_MESSAGESEARCHRESULT.fields_by_name['peer'].message_type = peers__pb2._PEER
_MESSAGESEARCHRESULT.fields_by_name['content'].message_type = messaging__pb2._MESSAGECONTENT
_MESSAGESEARCHITEM.fields_by_name['result'].message_type = _MESSAGESEARCHRESULT
_RESPONSEMESSAGESEARCHRESPONSE.fields_by_name['search_results'].message_type = _MESSAGESEARCHITEM
_RESPONSEMESSAGESEARCHRESPONSE.fields_by_name['users'].message_type = users__pb2._USER
_RESPONSEMESSAGESEARCHRESPONSE.fields_by_name['groups'].message_type = groups__pb2._GROUP
_RESPONSEMESSAGESEARCHRESPONSE.fields_by_name['load_more_state'].message_type = google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE
_RESPONSEMESSAGESEARCHRESPONSE.fields_by_name['user_out_peers'].message_type = peers__pb2._USEROUTPEER
_RESPONSEMESSAGESEARCHRESPONSE.fields_by_name['group_out_peers'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTMESSAGESEARCH.fields_by_name['query'].message_type = _SEARCHCONDITION
_REQUESTMESSAGESEARCH.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_REQUESTMESSAGESEARCHMORE.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_REQUESTSIMPLESEARCH.fields_by_name['criteria'].message_type = _SIMPLESEARCHCONDITION
_REQUESTSIMPLESEARCH.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_REQUESTSIMPLESEARCHMORE.fields_by_name['optimizations'].enum_type = miscellaneous__pb2._UPDATEOPTIMIZATION
_REQUESTLOADUSERSEARCHBYPREDICATESRESULTS.fields_by_name['predicates'].message_type = messaging__pb2._SEARCHPREDICATE
_REQUESTLOADUSERSEARCHBYPREDICATESRESULTS.fields_by_name['query'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSELOADUSERSEARCHBYPREDICATESRESULTS.fields_by_name['users'].message_type = _USERMATCH
_REQUESTLOADUSERSEARCHBYPREDICATESCOUNT.fields_by_name['predicates'].message_type = messaging__pb2._SEARCHPREDICATE
DESCRIPTOR.message_types_by_name['SimpleContactSearchCondition'] = _SIMPLECONTACTSEARCHCONDITION
DESCRIPTOR.message_types_by_name['SimpleMessageSearchCondition'] = _SIMPLEMESSAGESEARCHCONDITION
DESCRIPTOR.message_types_by_name['SimplePeerSearchCondition'] = _SIMPLEPEERSEARCHCONDITION
DESCRIPTOR.message_types_by_name['SimpleUserProfileSearchCondition'] = _SIMPLEUSERPROFILESEARCHCONDITION
DESCRIPTOR.message_types_by_name['criterion'] = _CRITERION
DESCRIPTOR.message_types_by_name['SimpleSearchCondition'] = _SIMPLESEARCHCONDITION
DESCRIPTOR.message_types_by_name['SearchCondition'] = _SEARCHCONDITION
DESCRIPTOR.message_types_by_name['SearchPeerTypeCondition'] = _SEARCHPEERTYPECONDITION
DESCRIPTOR.message_types_by_name['SearchPieceText'] = _SEARCHPIECETEXT
DESCRIPTOR.message_types_by_name['SearchAndCondition'] = _SEARCHANDCONDITION
DESCRIPTOR.message_types_by_name['SearchOrCondition'] = _SEARCHORCONDITION
DESCRIPTOR.message_types_by_name['SearchPeerCondition'] = _SEARCHPEERCONDITION
DESCRIPTOR.message_types_by_name['SearchPeerContentType'] = _SEARCHPEERCONTENTTYPE
DESCRIPTOR.message_types_by_name['SearchSenderIdConfition'] = _SEARCHSENDERIDCONFITION
DESCRIPTOR.message_types_by_name['PeerSearchResult'] = _PEERSEARCHRESULT
DESCRIPTOR.message_types_by_name['RequestPeerSearch'] = _REQUESTPEERSEARCH
DESCRIPTOR.message_types_by_name['ResponsePeerSearch'] = _RESPONSEPEERSEARCH
DESCRIPTOR.message_types_by_name['RequestResolvePeer'] = _REQUESTRESOLVEPEER
DESCRIPTOR.message_types_by_name['ResponseResolvePeer'] = _RESPONSERESOLVEPEER
DESCRIPTOR.message_types_by_name['MessageSearchResult'] = _MESSAGESEARCHRESULT
DESCRIPTOR.message_types_by_name['MessageSearchItem'] = _MESSAGESEARCHITEM
DESCRIPTOR.message_types_by_name['ResponseMessageSearchResponse'] = _RESPONSEMESSAGESEARCHRESPONSE
DESCRIPTOR.message_types_by_name['RequestMessageSearch'] = _REQUESTMESSAGESEARCH
DESCRIPTOR.message_types_by_name['RequestMessageSearchMore'] = _REQUESTMESSAGESEARCHMORE
DESCRIPTOR.message_types_by_name['RequestSimpleSearch'] = _REQUESTSIMPLESEARCH
DESCRIPTOR.message_types_by_name['RequestSimpleSearchMore'] = _REQUESTSIMPLESEARCHMORE
DESCRIPTOR.message_types_by_name['RequestFieldAutocomplete'] = _REQUESTFIELDAUTOCOMPLETE
DESCRIPTOR.message_types_by_name['ResponseFieldAutocomplete'] = _RESPONSEFIELDAUTOCOMPLETE
DESCRIPTOR.message_types_by_name['RequestLoadUserSearchByPredicatesResults'] = _REQUESTLOADUSERSEARCHBYPREDICATESRESULTS
DESCRIPTOR.message_types_by_name['UserMatch'] = _USERMATCH
DESCRIPTOR.message_types_by_name['ResponseLoadUserSearchByPredicatesResults'] = _RESPONSELOADUSERSEARCHBYPREDICATESRESULTS
DESCRIPTOR.message_types_by_name['RequestLoadUserSearchByPredicatesCount'] = _REQUESTLOADUSERSEARCHBYPREDICATESCOUNT
DESCRIPTOR.message_types_by_name['ResponseLoadUserSearchByPredicatesCount'] = _RESPONSELOADUSERSEARCHBYPREDICATESCOUNT
DESCRIPTOR.enum_types_by_name['SearchPeerType'] = _SEARCHPEERTYPE
DESCRIPTOR.enum_types_by_name['SearchContentType'] = _SEARCHCONTENTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SimpleContactSearchCondition = _reflection.GeneratedProtocolMessageType('SimpleContactSearchCondition', (_message.Message,), dict(
  DESCRIPTOR = _SIMPLECONTACTSEARCHCONDITION,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.SimpleContactSearchCondition)
  ))
_sym_db.RegisterMessage(SimpleContactSearchCondition)

SimpleMessageSearchCondition = _reflection.GeneratedProtocolMessageType('SimpleMessageSearchCondition', (_message.Message,), dict(
  DESCRIPTOR = _SIMPLEMESSAGESEARCHCONDITION,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.SimpleMessageSearchCondition)
  ))
_sym_db.RegisterMessage(SimpleMessageSearchCondition)

SimplePeerSearchCondition = _reflection.GeneratedProtocolMessageType('SimplePeerSearchCondition', (_message.Message,), dict(
  DESCRIPTOR = _SIMPLEPEERSEARCHCONDITION,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.SimplePeerSearchCondition)
  ))
_sym_db.RegisterMessage(SimplePeerSearchCondition)

SimpleUserProfileSearchCondition = _reflection.GeneratedProtocolMessageType('SimpleUserProfileSearchCondition', (_message.Message,), dict(
  DESCRIPTOR = _SIMPLEUSERPROFILESEARCHCONDITION,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.SimpleUserProfileSearchCondition)
  ))
_sym_db.RegisterMessage(SimpleUserProfileSearchCondition)

criterion = _reflection.GeneratedProtocolMessageType('criterion', (_message.Message,), dict(
  DESCRIPTOR = _CRITERION,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.criterion)
  ))
_sym_db.RegisterMessage(criterion)

SimpleSearchCondition = _reflection.GeneratedProtocolMessageType('SimpleSearchCondition', (_message.Message,), dict(
  DESCRIPTOR = _SIMPLESEARCHCONDITION,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.SimpleSearchCondition)
  ))
_sym_db.RegisterMessage(SimpleSearchCondition)

SearchCondition = _reflection.GeneratedProtocolMessageType('SearchCondition', (_message.Message,), dict(
  DESCRIPTOR = _SEARCHCONDITION,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.SearchCondition)
  ))
_sym_db.RegisterMessage(SearchCondition)

SearchPeerTypeCondition = _reflection.GeneratedProtocolMessageType('SearchPeerTypeCondition', (_message.Message,), dict(
  DESCRIPTOR = _SEARCHPEERTYPECONDITION,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.SearchPeerTypeCondition)
  ))
_sym_db.RegisterMessage(SearchPeerTypeCondition)

SearchPieceText = _reflection.GeneratedProtocolMessageType('SearchPieceText', (_message.Message,), dict(
  DESCRIPTOR = _SEARCHPIECETEXT,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.SearchPieceText)
  ))
_sym_db.RegisterMessage(SearchPieceText)

SearchAndCondition = _reflection.GeneratedProtocolMessageType('SearchAndCondition', (_message.Message,), dict(
  DESCRIPTOR = _SEARCHANDCONDITION,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.SearchAndCondition)
  ))
_sym_db.RegisterMessage(SearchAndCondition)

SearchOrCondition = _reflection.GeneratedProtocolMessageType('SearchOrCondition', (_message.Message,), dict(
  DESCRIPTOR = _SEARCHORCONDITION,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.SearchOrCondition)
  ))
_sym_db.RegisterMessage(SearchOrCondition)

SearchPeerCondition = _reflection.GeneratedProtocolMessageType('SearchPeerCondition', (_message.Message,), dict(
  DESCRIPTOR = _SEARCHPEERCONDITION,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.SearchPeerCondition)
  ))
_sym_db.RegisterMessage(SearchPeerCondition)

SearchPeerContentType = _reflection.GeneratedProtocolMessageType('SearchPeerContentType', (_message.Message,), dict(
  DESCRIPTOR = _SEARCHPEERCONTENTTYPE,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.SearchPeerContentType)
  ))
_sym_db.RegisterMessage(SearchPeerContentType)

SearchSenderIdConfition = _reflection.GeneratedProtocolMessageType('SearchSenderIdConfition', (_message.Message,), dict(
  DESCRIPTOR = _SEARCHSENDERIDCONFITION,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.SearchSenderIdConfition)
  ))
_sym_db.RegisterMessage(SearchSenderIdConfition)

PeerSearchResult = _reflection.GeneratedProtocolMessageType('PeerSearchResult', (_message.Message,), dict(
  DESCRIPTOR = _PEERSEARCHRESULT,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.PeerSearchResult)
  ))
_sym_db.RegisterMessage(PeerSearchResult)

RequestPeerSearch = _reflection.GeneratedProtocolMessageType('RequestPeerSearch', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTPEERSEARCH,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestPeerSearch)
  ))
_sym_db.RegisterMessage(RequestPeerSearch)

ResponsePeerSearch = _reflection.GeneratedProtocolMessageType('ResponsePeerSearch', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEPEERSEARCH,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponsePeerSearch)
  ))
_sym_db.RegisterMessage(ResponsePeerSearch)

RequestResolvePeer = _reflection.GeneratedProtocolMessageType('RequestResolvePeer', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTRESOLVEPEER,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestResolvePeer)
  ))
_sym_db.RegisterMessage(RequestResolvePeer)

ResponseResolvePeer = _reflection.GeneratedProtocolMessageType('ResponseResolvePeer', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSERESOLVEPEER,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseResolvePeer)
  ))
_sym_db.RegisterMessage(ResponseResolvePeer)

MessageSearchResult = _reflection.GeneratedProtocolMessageType('MessageSearchResult', (_message.Message,), dict(
  DESCRIPTOR = _MESSAGESEARCHRESULT,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.MessageSearchResult)
  ))
_sym_db.RegisterMessage(MessageSearchResult)

MessageSearchItem = _reflection.GeneratedProtocolMessageType('MessageSearchItem', (_message.Message,), dict(
  DESCRIPTOR = _MESSAGESEARCHITEM,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.MessageSearchItem)
  ))
_sym_db.RegisterMessage(MessageSearchItem)

ResponseMessageSearchResponse = _reflection.GeneratedProtocolMessageType('ResponseMessageSearchResponse', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEMESSAGESEARCHRESPONSE,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseMessageSearchResponse)
  ))
_sym_db.RegisterMessage(ResponseMessageSearchResponse)

RequestMessageSearch = _reflection.GeneratedProtocolMessageType('RequestMessageSearch', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTMESSAGESEARCH,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestMessageSearch)
  ))
_sym_db.RegisterMessage(RequestMessageSearch)

RequestMessageSearchMore = _reflection.GeneratedProtocolMessageType('RequestMessageSearchMore', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTMESSAGESEARCHMORE,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestMessageSearchMore)
  ))
_sym_db.RegisterMessage(RequestMessageSearchMore)

RequestSimpleSearch = _reflection.GeneratedProtocolMessageType('RequestSimpleSearch', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTSIMPLESEARCH,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSimpleSearch)
  ))
_sym_db.RegisterMessage(RequestSimpleSearch)

RequestSimpleSearchMore = _reflection.GeneratedProtocolMessageType('RequestSimpleSearchMore', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTSIMPLESEARCHMORE,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSimpleSearchMore)
  ))
_sym_db.RegisterMessage(RequestSimpleSearchMore)

RequestFieldAutocomplete = _reflection.GeneratedProtocolMessageType('RequestFieldAutocomplete', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTFIELDAUTOCOMPLETE,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestFieldAutocomplete)
  ))
_sym_db.RegisterMessage(RequestFieldAutocomplete)

ResponseFieldAutocomplete = _reflection.GeneratedProtocolMessageType('ResponseFieldAutocomplete', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEFIELDAUTOCOMPLETE,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseFieldAutocomplete)
  ))
_sym_db.RegisterMessage(ResponseFieldAutocomplete)

RequestLoadUserSearchByPredicatesResults = _reflection.GeneratedProtocolMessageType('RequestLoadUserSearchByPredicatesResults', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTLOADUSERSEARCHBYPREDICATESRESULTS,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestLoadUserSearchByPredicatesResults)
  ))
_sym_db.RegisterMessage(RequestLoadUserSearchByPredicatesResults)

UserMatch = _reflection.GeneratedProtocolMessageType('UserMatch', (_message.Message,), dict(
  DESCRIPTOR = _USERMATCH,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UserMatch)
  ))
_sym_db.RegisterMessage(UserMatch)

ResponseLoadUserSearchByPredicatesResults = _reflection.GeneratedProtocolMessageType('ResponseLoadUserSearchByPredicatesResults', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSELOADUSERSEARCHBYPREDICATESRESULTS,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseLoadUserSearchByPredicatesResults)
  ))
_sym_db.RegisterMessage(ResponseLoadUserSearchByPredicatesResults)

RequestLoadUserSearchByPredicatesCount = _reflection.GeneratedProtocolMessageType('RequestLoadUserSearchByPredicatesCount', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTLOADUSERSEARCHBYPREDICATESCOUNT,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestLoadUserSearchByPredicatesCount)
  ))
_sym_db.RegisterMessage(RequestLoadUserSearchByPredicatesCount)

ResponseLoadUserSearchByPredicatesCount = _reflection.GeneratedProtocolMessageType('ResponseLoadUserSearchByPredicatesCount', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSELOADUSERSEARCHBYPREDICATESCOUNT,
  __module__ = 'search_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseLoadUserSearchByPredicatesCount)
  ))
_sym_db.RegisterMessage(ResponseLoadUserSearchByPredicatesCount)


DESCRIPTOR._options = None
_SEARCHPEERTYPECONDITION.fields_by_name['peer_type']._options = None
_SEARCHPIECETEXT.fields_by_name['query']._options = None
_SEARCHANDCONDITION.fields_by_name['and_query']._options = None
_SEARCHORCONDITION.fields_by_name['or_query']._options = None
_SEARCHPEERCONDITION.fields_by_name['peer']._options = None
_SEARCHPEERCONTENTTYPE.fields_by_name['content_type']._options = None
_SEARCHSENDERIDCONFITION.fields_by_name['sender_id']._options = None
_PEERSEARCHRESULT.fields_by_name['peer']._options = None
_PEERSEARCHRESULT.fields_by_name['title']._options = None
_PEERSEARCHRESULT.fields_by_name['description']._options = None
_PEERSEARCHRESULT.fields_by_name['members_count']._options = None
_PEERSEARCHRESULT.fields_by_name['date_created']._options = None
_PEERSEARCHRESULT.fields_by_name['creator']._options = None
_PEERSEARCHRESULT.fields_by_name['is_public']._options = None
_REQUESTPEERSEARCH.fields_by_name['query']._options = None
_REQUESTPEERSEARCH.fields_by_name['optimizations']._options = None
_REQUESTPEERSEARCH._options = None
_RESPONSEPEERSEARCH._options = None
_REQUESTRESOLVEPEER.fields_by_name['shortname']._options = None
_REQUESTRESOLVEPEER._options = None
_RESPONSERESOLVEPEER._options = None
_MESSAGESEARCHRESULT.fields_by_name['peer']._options = None
_MESSAGESEARCHRESULT.fields_by_name['rid']._options = None
_MESSAGESEARCHRESULT.fields_by_name['date']._options = None
_MESSAGESEARCHRESULT.fields_by_name['sender_id']._options = None
_MESSAGESEARCHRESULT.fields_by_name['content']._options = None
_RESPONSEMESSAGESEARCHRESPONSE.fields_by_name['search_results']._options = None
_RESPONSEMESSAGESEARCHRESPONSE.fields_by_name['users']._options = None
_RESPONSEMESSAGESEARCHRESPONSE.fields_by_name['groups']._options = None
_RESPONSEMESSAGESEARCHRESPONSE.fields_by_name['load_more_state']._options = None
_RESPONSEMESSAGESEARCHRESPONSE.fields_by_name['user_out_peers']._options = None
_RESPONSEMESSAGESEARCHRESPONSE.fields_by_name['group_out_peers']._options = None
_RESPONSEMESSAGESEARCHRESPONSE._options = None
_REQUESTMESSAGESEARCH.fields_by_name['query']._options = None
_REQUESTMESSAGESEARCH.fields_by_name['optimizations']._options = None
_REQUESTMESSAGESEARCH._options = None
_REQUESTMESSAGESEARCHMORE.fields_by_name['load_more_state']._options = None
_REQUESTMESSAGESEARCHMORE.fields_by_name['optimizations']._options = None
_REQUESTMESSAGESEARCHMORE._options = None
_REQUESTSIMPLESEARCH._options = None
_REQUESTSIMPLESEARCHMORE._options = None
_REQUESTFIELDAUTOCOMPLETE.fields_by_name['field_name']._options = None
_REQUESTFIELDAUTOCOMPLETE.fields_by_name['field_value']._options = None
_REQUESTFIELDAUTOCOMPLETE._options = None
_RESPONSEFIELDAUTOCOMPLETE.fields_by_name['field_name']._options = None
_RESPONSEFIELDAUTOCOMPLETE.fields_by_name['field_value']._options = None
_RESPONSEFIELDAUTOCOMPLETE._options = None
_REQUESTLOADUSERSEARCHBYPREDICATESRESULTS.fields_by_name['predicates']._options = None
_REQUESTLOADUSERSEARCHBYPREDICATESRESULTS.fields_by_name['group_id']._options = None
_REQUESTLOADUSERSEARCHBYPREDICATESRESULTS.fields_by_name['query']._options = None
_REQUESTLOADUSERSEARCHBYPREDICATESRESULTS.fields_by_name['limit']._options = None
_REQUESTLOADUSERSEARCHBYPREDICATESRESULTS.fields_by_name['required_fields']._options = None
_REQUESTLOADUSERSEARCHBYPREDICATESRESULTS._options = None
_USERMATCH.fields_by_name['user_id']._options = None
_USERMATCH.fields_by_name['match_predicates']._options = None
_RESPONSELOADUSERSEARCHBYPREDICATESRESULTS.fields_by_name['users']._options = None
_RESPONSELOADUSERSEARCHBYPREDICATESRESULTS.fields_by_name['result_count']._options = None
_RESPONSELOADUSERSEARCHBYPREDICATESRESULTS._options = None
_REQUESTLOADUSERSEARCHBYPREDICATESCOUNT.fields_by_name['predicates']._options = None
_REQUESTLOADUSERSEARCHBYPREDICATESCOUNT.fields_by_name['group_id']._options = None
_REQUESTLOADUSERSEARCHBYPREDICATESCOUNT._options = None
_RESPONSELOADUSERSEARCHBYPREDICATESCOUNT.fields_by_name['result_count']._options = None
_RESPONSELOADUSERSEARCHBYPREDICATESCOUNT._options = None

_SEARCH = _descriptor.ServiceDescriptor(
  name='Search',
  full_name='dialog.Search',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=5601,
  serialized_end=6904,
  methods=[
  _descriptor.MethodDescriptor(
    name='PeerSearch',
    full_name='dialog.Search.PeerSearch',
    index=0,
    containing_service=None,
    input_type=_REQUESTPEERSEARCH,
    output_type=_RESPONSEPEERSEARCH,
    serialized_options=_b('\202\323\344\223\002\037\"\032/v1/grpc/Search/PeerSearch:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='ResolvePeer',
    full_name='dialog.Search.ResolvePeer',
    index=1,
    containing_service=None,
    input_type=_REQUESTRESOLVEPEER,
    output_type=_RESPONSERESOLVEPEER,
    serialized_options=_b('\202\323\344\223\002 \"\033/v1/grpc/Search/ResolvePeer:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='MessageSearch',
    full_name='dialog.Search.MessageSearch',
    index=2,
    containing_service=None,
    input_type=_REQUESTMESSAGESEARCH,
    output_type=_RESPONSEMESSAGESEARCHRESPONSE,
    serialized_options=_b('\202\323\344\223\002\"\"\035/v1/grpc/Search/MessageSearch:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='MessageSearchMore',
    full_name='dialog.Search.MessageSearchMore',
    index=3,
    containing_service=None,
    input_type=_REQUESTMESSAGESEARCHMORE,
    output_type=_RESPONSEMESSAGESEARCHRESPONSE,
    serialized_options=_b('\202\323\344\223\002&\"!/v1/grpc/Search/MessageSearchMore:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='SimpleSearch',
    full_name='dialog.Search.SimpleSearch',
    index=4,
    containing_service=None,
    input_type=_REQUESTSIMPLESEARCH,
    output_type=_RESPONSEMESSAGESEARCHRESPONSE,
    serialized_options=_b('\202\323\344\223\002!\"\034/v1/grpc/Search/SimpleSearch:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='SimpleSearchMore',
    full_name='dialog.Search.SimpleSearchMore',
    index=5,
    containing_service=None,
    input_type=_REQUESTSIMPLESEARCHMORE,
    output_type=_RESPONSEMESSAGESEARCHRESPONSE,
    serialized_options=_b('\202\323\344\223\002%\" /v1/grpc/Search/SimpleSearchMore:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='AutocompleteSuggestions',
    full_name='dialog.Search.AutocompleteSuggestions',
    index=6,
    containing_service=None,
    input_type=_REQUESTFIELDAUTOCOMPLETE,
    output_type=_RESPONSEFIELDAUTOCOMPLETE,
    serialized_options=_b('\202\323\344\223\002,\"\'/v1/grpc/Search/AutocompleteSuggestions:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='LoadUserSearchByPredicatesResults',
    full_name='dialog.Search.LoadUserSearchByPredicatesResults',
    index=7,
    containing_service=None,
    input_type=_REQUESTLOADUSERSEARCHBYPREDICATESRESULTS,
    output_type=_RESPONSELOADUSERSEARCHBYPREDICATESRESULTS,
    serialized_options=_b('\202\323\344\223\0026\"1/v1/grpc/Search/LoadUserSearchByPredicatesResults:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='LoadUserSearchByPredicatesCount',
    full_name='dialog.Search.LoadUserSearchByPredicatesCount',
    index=8,
    containing_service=None,
    input_type=_REQUESTLOADUSERSEARCHBYPREDICATESCOUNT,
    output_type=_RESPONSELOADUSERSEARCHBYPREDICATESCOUNT,
    serialized_options=_b('\202\323\344\223\0024\"//v1/grpc/Search/LoadUserSearchByPredicatesCount:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_SEARCH)

DESCRIPTOR.services_by_name['Search'] = _SEARCH

# @@protoc_insertion_point(module_scope)



from .service import ManagedService
from .dialog_api import sequence_and_updates_pb2, miscellaneous_pb2

DEFAULT_OPTIMIZATIONS = [
    miscellaneous_pb2.UPDATEOPTIMIZATION_STRIP_ENTITIES,
    miscellaneous_pb2.UPDATEOPTIMIZATION_STRIP_ENTITIES_V2,
    miscellaneous_pb2.UPDATEOPTIMIZATION_STRIP_COUNTERS,
    miscellaneous_pb2.UPDATEOPTIMIZATION_COMPACT_USERS
]


class Updates(ManagedService):
    """Class for handling grpc's server updates.

    """
    def get_difference(self, seq):
        """Raw implementation of API schema GetDifference method, which returns updates between attribute 'seq' and
        current seq at server side.

        :param seq: seq value
        :return: GetDifferenceResponse object
        """
        diff = self.internal.updates.GetDifference(
            sequence_and_updates_pb2.RequestGetDifference(
                seq=seq,
                optimizations=DEFAULT_OPTIMIZATIONS
            )
        )

        return diff



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import miscellaneous_pb2 as miscellaneous__pb2
from . import web_rtc_pb2 as web__rtc__pb2


class WebRTCStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetCallInfo = channel.unary_unary(
        '/dialog.WebRTC/GetCallInfo',
        request_serializer=web__rtc__pb2.RequestGetCallInfo.SerializeToString,
        response_deserializer=web__rtc__pb2.ResponseGetCallInfo.FromString,
        )
    self.LoadCalls = channel.unary_unary(
        '/dialog.WebRTC/LoadCalls',
        request_serializer=web__rtc__pb2.RequestLoadCalls.SerializeToString,
        response_deserializer=web__rtc__pb2.ResponseLoadCalls.FromString,
        )
    self.DoCall = channel.unary_unary(
        '/dialog.WebRTC/DoCall',
        request_serializer=web__rtc__pb2.RequestDoCall.SerializeToString,
        response_deserializer=web__rtc__pb2.ResponseDoCall.FromString,
        )
    self.JoinCall = channel.unary_unary(
        '/dialog.WebRTC/JoinCall',
        request_serializer=web__rtc__pb2.RequestJoinCall.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.RejectCall = channel.unary_unary(
        '/dialog.WebRTC/RejectCall',
        request_serializer=web__rtc__pb2.RequestRejectCall.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.ChangeCallDisplayName = channel.unary_unary(
        '/dialog.WebRTC/ChangeCallDisplayName',
        request_serializer=web__rtc__pb2.RequestChangeCallDisplayName.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.DeleteCall = channel.unary_unary(
        '/dialog.WebRTC/DeleteCall',
        request_serializer=web__rtc__pb2.RequestDeleteCall.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )


class WebRTCServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def GetCallInfo(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def LoadCalls(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DoCall(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def JoinCall(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RejectCall(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ChangeCallDisplayName(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteCall(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_WebRTCServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetCallInfo': grpc.unary_unary_rpc_method_handler(
          servicer.GetCallInfo,
          request_deserializer=web__rtc__pb2.RequestGetCallInfo.FromString,
          response_serializer=web__rtc__pb2.ResponseGetCallInfo.SerializeToString,
      ),
      'LoadCalls': grpc.unary_unary_rpc_method_handler(
          servicer.LoadCalls,
          request_deserializer=web__rtc__pb2.RequestLoadCalls.FromString,
          response_serializer=web__rtc__pb2.ResponseLoadCalls.SerializeToString,
      ),
      'DoCall': grpc.unary_unary_rpc_method_handler(
          servicer.DoCall,
          request_deserializer=web__rtc__pb2.RequestDoCall.FromString,
          response_serializer=web__rtc__pb2.ResponseDoCall.SerializeToString,
      ),
      'JoinCall': grpc.unary_unary_rpc_method_handler(
          servicer.JoinCall,
          request_deserializer=web__rtc__pb2.RequestJoinCall.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'RejectCall': grpc.unary_unary_rpc_method_handler(
          servicer.RejectCall,
          request_deserializer=web__rtc__pb2.RequestRejectCall.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'ChangeCallDisplayName': grpc.unary_unary_rpc_method_handler(
          servicer.ChangeCallDisplayName,
          request_deserializer=web__rtc__pb2.RequestChangeCallDisplayName.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'DeleteCall': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteCall,
          request_deserializer=web__rtc__pb2.RequestDeleteCall.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'dialog.WebRTC', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
